# HyResBuilder: A simple package for building HyRes peptide model.   
This package is forked from [PeptideBuilder](https://github.com/clauswilke/PeptideBuilder) and we do some modifications for HyRes.   
Shanlong Li 
